# cli_ospf_data Templates

This template designed for use with N2G library to produce network diagrams based on OSPF 
link state database of network devices. 

Caveats:

 - need `ttp>=0.8.0` for extend to work

Results structure example:

```
TBD
```